@@ -23,8 +23,8 @@ class kafkaHelper:
         self.topic = topic
         self.producer=None
         self.consumer=None
-        self.pub_key = Fernet.generate_key()
-        self.fernet = Fernet(self.pub_key)
+        self.fernet_key = Fernet.generate_key()
+        self.fernet = Fernet(self.fernet_key)
         self.admin_client = KafkaAdminClient(bootstrap_servers=self.bootstrap_servers)
         
 
@@ -59,6 +59,7 @@ class kafkaHelper:
         if self.consumer:
             self.consumer.close()
 
+
     def topic_exists(self, admin_client, topic_name):
         """
         [{'error_code': 3, 'topic': 'c', 'is_internal': False, 'partitions': []}, 
